<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features
 */

if ( ! function_exists( 'good_comment' ) ) :

	function good_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="clearfix">
			<header class="comment-author vcard">
				<?php echo get_avatar( $comment, $size = '45' ); ?>
				<?php printf( __( '<cite class="fn">%s</cite>', 'good' ), get_comment_author_link() ) ?>
				<p class="meta">
					<?php
					/* translators: 1. Comment Date & Time 2. Reply Link */
					printf(
						__( '%1$s, %2$s', 'good' ),
						'<a href="'. htmlspecialchars( get_comment_link( $comment->comment_ID ) ) . '">' . get_comment_date( get_option( 'date_format' ) ) . ' ' . get_comment_time( get_option( 'time_format' ) ) . '</a>',
						get_comment_reply_link( array_merge( $args, array(
							'depth'     => $depth,
							'max_depth' => $args['max_depth']
						) ) )
					); ?>
				</p>
			</header>

			<?php if ( $comment->comment_approved == '0' ) : ?>
				<div class="help">
					<p><?php _e( 'Your comment is awaiting moderation.', 'good' ) ?></p>
				</div>
			<?php endif; ?>

			<section class="comment_content clearfix">
				<?php comment_text() ?>
			</section>
		</article>
		<?php
		/* </li> is added by wordpress automatically */
	}

endif;


if ( ! function_exists( 'good_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function good_posted_on() {
		printf( __( '<time class="entry-date" datetime="%1$s">%2$s</time>', 'good' ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);
	}
endif;


/**
 * Returns true if a blog has more than 1 category
 */
function good_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'good_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'good_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so good_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so good_categorized_blog should return false
		return false;
	}
}


/**
 * Flush out the transients used in good_categorized_blog
 */
function good_category_transient_flusher() {
	// Like, beat it. Dig?
	delete_transient( 'good_the_cool_cats' );
}

add_action( 'edit_category', 'good_category_transient_flusher' );
add_action( 'save_post', 'good_category_transient_flusher' );


/**
 * Get related post, with the same category
 */
function good_related_posts() {
	$post          = get_post();
	$category      = get_the_category( $post->ID );
	$cat_id        = $category[0]->cat_ID;
	$args          = array(
		'cat'          => $cat_id,
		'showposts'    => 3,
		'post__not_in' => array( $post->ID )
	);
	$related_posts = new WP_Query( $args );

	if ( ! $related_posts->have_posts() ) {
		return;
	} ?>

	<div class="site-content group posts-block three-columns">
		<?php
		while ( $related_posts->have_posts() ) : $related_posts->the_post();

			get_template_part( 'template-parts/content-widget', 'three-columns' );

		endwhile;

		wp_reset_query();
		?>
	</div>

	<?php
	wp_reset_query();
}


/**
 * Breadcrumbs
 */
function good_breadcrumb() {

	if ( ! is_front_page() ) {
		echo '<div id="breadcrumbs"> <a href="' . home_url() . '">' . __( 'Home', 'good' ) . '</a> ';
	}

	if ( ( is_category() || is_single() ) && ! is_attachment() ) {
		$category = get_the_category();

		if ( count( $category ) > 0 ) {
			$ID = $category[0]->cat_ID;
			if ( $ID ) {
				echo get_category_parents( $ID, true, ' ', false );
			}
		}
	}

	if ( ! is_front_page() && ( is_single() || is_page() ) ) {
		the_title();
	}
	if ( is_tag() ) {
		printf(  __( 'Tag: %s', 'good' ), single_tag_title( '', false ) );
	}
	if ( is_404() ) {
		_e( '404 - Page not Found', 'good' );
	}
	if ( is_search() ) {
		_e( 'Search', 'good' );
	}
	if ( is_year() ) {
		echo get_the_time( 'Y' );
	}
	if ( is_month() ) {
		echo get_the_time( 'F Y' );
	}
	if ( is_author() ) {
		printf( __( 'Posts by %s', 'good' ), get_the_author() );
	}

	if ( ! is_front_page() ) {
		echo "</div>";
	}
}


/**
 * Page Navigation
 */
function good_pagenavi( $the_query = '' ) {
	global $theme_options;
	if ( $the_query ) {
		$wp_query = $the_query;
	} else {
		global $wp_query;
	}
	$show_number = 2;
	$total       = $wp_query->max_num_pages;

	if ( $total > 1 ) {
		if ( ! $current_page = get_query_var( 'paged' ) ) {
			$current_page = 1;
		}

		if ( ! get_option( 'permalink_structure' ) ) {
			$format = '&paged=%#%';
			if ( is_home() ) {
				$format = '?paged=%#%';
			}
		} else {
			$format = '/page/%#%/';
		}

		if ( is_search() ) {
			$format = '&paged=%#%';
		}

		echo '<nav class="page-navigation">';
		$paginate = paginate_links( array(
			'base'      => untrailingslashit( get_pagenum_link( 1 ) ) . '%_%',
			'format'    => $format,
			'current'   => $current_page,
			'total'     => $total,
			'show_all'  => true,
			'type'      => 'array',
			'prev_text' => __( 'Prev', 'good' ),
			'next_text' => __( 'Next', 'good' ),
		) );
		$fi       = 0;
		$prev     = '';
		$first    = '';
		$left_dot = '';
		if ( strpos( $paginate[0], 'prev' ) !== false ) {
			$fi   = 1;
			$prev = '<li>' . $paginate[0] . '</li>';
			if ( ( $current_page - $show_number ) > 1 ) {
				$fi       = $current_page - $show_number;
				$first    = '<li>' . preg_replace( '/>[^>]*[^<]</', '>First<', $paginate[1] ) . '</li>';
				$left_dot = '<li><span>...</span></li>';
			}
		}
		$la        = count( $paginate ) - 1;
		$next      = '';
		$last      = '';
		$right_dot = '';
		if ( strpos( $paginate[ count( $paginate ) - 1 ], 'next' ) !== false ) {
			$la   = count( $paginate ) - 2;
			$next = '<li>' . $paginate[ count( $paginate ) - 1 ] . '</li>';
			if ( ( $current_page + $show_number ) < $total ) {
				$la        = $current_page + $show_number;
				$last      = '<li>' . preg_replace( '/>[^>]*[^<]</', '>Last<', $paginate[ count( $paginate ) - 2 ] ) . '</li>';
				$right_dot = '<li><span>...</span></li>';
			}
		}

		//echo '<span class="page-of">'. __('Page', 'good') . ' ' . $current_page . __(' of ', 'good') . $total . '</span>';
		echo '<ul class="page_navi clearfix">';
		echo $first . $left_dot;
		echo $prev;
		for ( $i = $fi; $i <= $la; $i ++ ) {
			echo '<li>' . $paginate[ $i ] . '</li>';
		}
		echo $right_dot . $last;
		echo $next;
		echo '</ul>';
		echo '</nav>';
	} else {
		echo '<nav class="page-navigation">';
		echo '</nav>';
	}
}
